#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "view3d.h"
#include <QFileDialog>
#include <QMessageBox>
#include <QIcon>
#include <QSettings>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
	ui->setupUi(this);
	ui->mainToolBar->addActions(QList<QAction*>() << ui->action_Open << ui->action_Save_as << ui->action_Exit);

	setCentralWidget(view3d = new View3d);

	connect(ui->action_Open, SIGNAL(triggered()), this, SLOT(file_open()));
	connect(ui->action_Save_as, SIGNAL(triggered()), this, SLOT(file_save()));
	connect(ui->action_About, SIGNAL(triggered()), this, SLOT(help_about()));
	connect(ui->action_About_Qt, SIGNAL(triggered()), this, SLOT(help_about_qt()));

	loadSettings();
}

MainWindow::~MainWindow()
{
	delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
	QMainWindow::changeEvent(e);
	switch (e->type()) {
	case QEvent::LanguageChange:
		ui->retranslateUi(this);
		break;
	default:
		break;
	}
}

void MainWindow::closeEvent(QCloseEvent *)
{
	QSettings settings;
	settings.beginGroup("MainWindow");
	settings.setValue("geometry", geometry());
	settings.endGroup();
}

void MainWindow::loadSettings()
{
	QSettings settings;
	settings.beginGroup("MainWindow");
	setGeometry(settings.value("geometry", geometry()).toRect());
	settings.endGroup();
}

void MainWindow::file_open()
{
	const QString &filename = QFileDialog::getOpenFileName(this, tr("Open mesh"), QString(), tr("3D Meshes (*.obj *.ply *.off *.stl *.3ds)"));
	if (filename.isEmpty())
		return;
	view3d->load(filename);
}

void MainWindow::file_save()
{
	const QString &filename = QFileDialog::getSaveFileName(this, tr("Save mesh"), QString(), tr("PLY file (*.ply);;OFF file (*.off);;STL file (*.stl)"));
	if (filename.isEmpty())
		return;
	view3d->save(filename);
}

void MainWindow::help_about()
{
	QMessageBox::about(this, tr("About QMeshViewer"), tr("ABOUT_QMESHVIEWER"));
}

void MainWindow::help_about_qt()
{
	QMessageBox::aboutQt(this);
}

void MainWindow::loadMesh(const QString &filename)
{
	view3d->load(filename);
}
